==> estateplat-common-1.2.4-20210325.094450-679-sources.jar: cn/gtmap/estateplat/model/exchange/unidofrmity/DjfDjSqrBdc.java <==
package cn.gtmap.estateplat.model.exchange.unidofrmity;

import cn.gtmap.estateplat.model.exchange.national.DjfDjSqr;
import cn.gtmap.estateplat.utils.JaxbStringAdapter;
import cn.gtmap.estateplat.utils.JaxbStringNoNullAdapter;

import javax.xml.bind.annotation.XmlAttribute;
import javax.xml.bind.annotation.adapters.XmlJavaTypeAdapter;

public class DjfDjSqrBdc extends DjfDjSqr {
    private String dfqlrzjzldm;
    private String dfqlrzjzlmc;
    private String dfywrzjzldm;
    private String dfywrzjzlmc;
    @XmlAttribute(
            name = "DFQLRZJZLDM"
    )
    @XmlJavaTypeAdapter(JaxbStringAdapter.class)
    public String getDfqlrzjzldm() {
        return dfqlrzjzldm;
    }

    public void setDfqlrzjzldm(String dfqlrzjzldm) {
        this.dfqlrzjzldm = dfqlrzjzldm;
    }
    @XmlAttribute(
            name = "DFQLRZJZLMC"
    )
    @XmlJavaTypeAdapter(JaxbStringAdapter.class)
    public String getDfqlrzjzlmc() {
        return dfqlrzjzlmc;
    }

    public void setDfqlrzjzlmc(String dfqlrzjzlmc) {
        this.dfqlrzjzlmc = dfqlrzjzlmc;
    }
    @XmlAttribute(
            name = "DFYWRZJZLDM"
    )
    @XmlJavaTypeAdapter(JaxbStringAdapter.class)
    public String getDfywrzjzldm() {
        return dfywrzjzldm;
    }

    public void setDfywrzjzldm(String dfywrzjzldm) {
        this.dfywrzjzldm = dfywrzjzldm;
    }
    @XmlAttribute(
            name = "DFYWRZJZLMC"
    )
    @XmlJavaTypeAdapter(JaxbStringAdapter.class)
    public String getDfywrzjzlmc() {
        return dfywrzjzlmc;
    }

    public void setDfywrzjzlmc(String dfywrzjzlmc) {
        this.dfywrzjzlmc = dfywrzjzlmc;
    }
}

==> estateplat-common-1.2.4-20241103.075815-1264-sources.jar: cn/gtmap/estateplat/model/exchange/unidofrmity/DjfDjSqrBdc.java <==
package cn.gtmap.estateplat.model.exchange.unidofrmity;

import cn.gtmap.estateplat.model.exchange.national.newStandard.DjfDjSqrNew;
import cn.gtmap.estateplat.utils.JaxbStringAdapter;
import javax.xml.bind.annotation.XmlAttribute;
import javax.xml.bind.annotation.adapters.XmlJavaTypeAdapter;

public class DjfDjSqrBdc extends DjfDjSqrNew {
    private String dfqlrzjzldm;
    private String dfqlrzjzlmc;
    private String dfywrzjzldm;
    private String dfywrzjzlmc;
    @XmlAttribute(
            name = "DFQLRZJZLDM"
    )
    @XmlJavaTypeAdapter(JaxbStringAdapter.class)
    public String getDfqlrzjzldm() {
        return dfqlrzjzldm;
    }

    public void setDfqlrzjzldm(String dfqlrzjzldm) {
        this.dfqlrzjzldm = dfqlrzjzldm;
    }
    @XmlAttribute(
            name = "DFQLRZJZLMC"
    )
    @XmlJavaTypeAdapter(JaxbStringAdapter.class)
    public String getDfqlrzjzlmc() {
        return dfqlrzjzlmc;
    }

    public void setDfqlrzjzlmc(String dfqlrzjzlmc) {
        this.dfqlrzjzlmc = dfqlrzjzlmc;
    }
    @XmlAttribute(
            name = "DFYWRZJZLDM"
    )
    @XmlJavaTypeAdapter(JaxbStringAdapter.class)
    public String getDfywrzjzldm() {
        return dfywrzjzldm;
    }

    public void setDfywrzjzldm(String dfywrzjzldm) {
        this.dfywrzjzldm = dfywrzjzldm;
    }
    @XmlAttribute(
            name = "DFYWRZJZLMC"
    )
    @XmlJavaTypeAdapter(JaxbStringAdapter.class)
    public String getDfywrzjzlmc() {
        return dfywrzjzlmc;
    }

    public void setDfywrzjzlmc(String dfywrzjzlmc) {
        this.dfywrzjzlmc = dfywrzjzlmc;
    }
}
